Index: demo/disjoint_paths_demo.cc
===================================================================
--- demo/disjoint_paths_demo.cc	(revision 2084)
+++ demo/disjoint_paths_demo.cc	(revision 2174)
@@ -42,5 +42,5 @@
 
 Color color(bool b) {
-  return b ? Color(1.0, 0.0, 0.0) : Color(0.0, 0.0, 0.0);
+  return b ? RED : BLACK;
 }
 
Index: demo/strongly_connected_orientation.cc
===================================================================
--- demo/strongly_connected_orientation.cc	(revision 2173)
+++ demo/strongly_connected_orientation.cc	(revision 2174)
@@ -46,5 +46,5 @@
 
 Color color(bool c) {
-  return c ? Color(0.0, 0.0, 0.0) : Color(1.0, 0.0, 0.0);
+  return c ? BLACK : RED;
 }
 
Index: demo/topology_demo.cc
===================================================================
--- demo/topology_demo.cc	(revision 2172)
+++ demo/topology_demo.cc	(revision 2174)
@@ -41,5 +41,5 @@
 
 Color color(bool val) {
-  return val ? Color(1.0, 0.0, 0.0) : Color(0.0, 0.0, 1.0);
+  return val ? RED : BLUE;
 }
 
Index: lemon/Makefile.am
===================================================================
--- lemon/Makefile.am	(revision 2144)
+++ lemon/Makefile.am	(revision 2174)
@@ -11,4 +11,5 @@
 	lemon/lp_skeleton.cc \
 	lemon/base.cc \
+	lemon/color.cc \
 	lemon/eps.cc \
 	lemon/bits/mingw32_rand.cc \
Index: lemon/color.cc
===================================================================
--- lemon/color.cc	(revision 2174)
+++ lemon/color.cc	(revision 2174)
@@ -0,0 +1,44 @@
+ /* -*- C++ -*-
+ *
+ * This file is a part of LEMON, a generic C++ optimization library
+ *
+ * Copyright (C) 2003-2006
+ * Egervary Jeno Kombinatorikus Optimalizalasi Kutatocsoport
+ * (Egervary Research Group on Combinatorial Optimization, EGRES).
+ *
+ * Permission to use, modify and distribute this software is granted
+ * provided that this copyright notice appears in all copies. For
+ * precise terms see the accompanying LICENSE file.
+ *
+ * This software is provided "AS IS" with no warranty of any kind,
+ * express or implied, and with no claim as to its suitability for any
+ * purpose.
+ *
+ */
+
+///\file
+///\brief Color constants
+
+#include<lemon/color.h>
+
+namespace lemon {
+
+  const Color WHITE(1,1,1);
+  
+  const Color BLACK(0,0,0);
+  const Color RED(1,0,0);
+  const Color GREEN(0,1,0);
+  const Color BLUE(0,0,1);
+  const Color YELLOW(1,1,0);
+  const Color MAGENTA(1,0,1);
+  const Color CYAN(0,1,1);
+
+  const Color GREY(0,0,0);
+  const Color DARK_RED(.5,0,0);
+  const Color DARK_GREEN(0,.5,0);
+  const Color DARK_BLUE(0,0,.5);
+  const Color DARK_YELLOW(.5,.5,0);
+  const Color DARK_MAGENTA(.5,0,.5);
+  const Color DARK_CYAN(0,.5,.5);
+    
+} //namespace lemon
Index: lemon/eps.h
===================================================================
--- lemon/eps.h	(revision 2084)
+++ lemon/eps.h	(revision 2174)
@@ -287,5 +287,5 @@
     ///\param brd Color of the node border. The default color is black
     EpsDrawer &node(NodeShapes t, double x, double y, double r,
-		    Color col=Color(1,1,1), Color brd=Color(0,0,0));
+		    Color col=WHITE, Color brd=BLACK);
     ///Draw a node shape
     
@@ -298,5 +298,5 @@
     template<class T>
     EpsDrawer &node(NodeShapes t, xy<T> pos, double r,
-		    Color col=Color(1,1,1), Color brd=Color(0,0,0))
+		    Color col=WHITE, Color brd=BLACK)
     {
       return node(t,pos.x,pos.y,r,col,brd);
Index: lemon/graph_to_eps.h
===================================================================
--- lemon/graph_to_eps.h	(revision 2172)
+++ lemon/graph_to_eps.h	(revision 2174)
@@ -145,5 +145,5 @@
     g(_g), os(_os),
     _coords(xy<double>(1,1)), _nodeSizes(1.0), _nodeShapes(0),
-    _nodeColors(Color(1,1,1)), _edgeColors(Color(0,0,0)),
+    _nodeColors(WHITE), _edgeColors(BLACK),
     _edgeWidths(1), _edgeWidthScale(0.3),
     _nodeScale(1.0), _xBorder(10), _yBorder(10), _scale(1.0),
@@ -156,5 +156,5 @@
     _undirected(false),
     _pleaseRemoveOsStream(_pros), _scaleToA4(false),
-    _nodeTextColorType(SAME_COL), _nodeTextColors(Color(0,0,0)),
+    _nodeTextColorType(SAME_COL), _nodeTextColors(BLACK),
     _autoNodeScale(false),
     _autoEdgeWidthScale(false),

Index: lemon/color.h
===================================================================
--- lemon/color.h	(revision 2172)
+++ lemon/color.h	(revision 2174)
@@ -44,4 +44,7 @@
 
 namespace lemon {
+
+  /// \addtogroup misc
+  /// @{
 
 ///Data structure representing RGB colors.
@@ -73,4 +76,35 @@
 };
 
+  /// White color constant
+  extern const Color WHITE;  
+  /// Black color constant
+  extern const Color BLACK;
+  /// Red color constant
+  extern const Color RED;
+  /// Green color constant
+  extern const Color GREEN;
+  /// Blue color constant
+  extern const Color BLUE;
+  /// Yellow color constant
+  extern const Color YELLOW;
+  /// Magenta color constant
+  extern const Color MAGENTA;
+  /// Cyan color constant
+  extern const Color CYAN;
+  /// Grey color constant
+  extern const Color GREY;
+  /// Dark red color constant
+  extern const Color DARK_RED;
+  /// Dark green color constant
+  extern const Color DARK_GREEN;
+  /// Drak blue color constant
+  extern const Color DARK_BLUE;
+  /// Dark yellow color constant
+  extern const Color DARK_YELLOW;
+  /// Dark magenta color constant
+  extern const Color DARK_MAGENTA;
+  /// Dark cyan color constant
+  extern const Color DARK_CYAN;
+
 ///Maps <tt>int</tt>s to different \ref Color "Color"s
 
@@ -92,6 +126,6 @@
   ///amongst the provided color (\c true) or not (\c false). If it is true,
   ///white will be assigned to \c 0.
   ///\param num the number of the allocated colors. If it is \c 0
   ///the default color configuration is set up (26 color plus the while).
   ///If \c num is less then 26/27 then the default color list is cut. Otherwise
   ///the color list is filled repeatedly with the default color list.
@@ -168,8 +202,9 @@
 ///Returns black for light colors and white for the dark ones.
 inline Color distantBW(const Color &c){
-  double v=(.2125*c.red()+.7154*c.green()+.0721*c.blue())<.5?1:0;
-  return Color(v,v,v);
+  return (.2125*c.red()+.7154*c.green()+.0721*c.blue())<.5 ? WHITE : BLACK;
 }
 
+/// @}
+
 } //END OF NAMESPACE LEMON
 
@@ -92,6 +126,6 @@
   ///amongst the provided color (\c true) or not (\c false). If it is true,
   ///white will be assigned to \c 0.
-  ///\param num the number of the allocated colors. If it is \c 0
-  ///the default color configuration is set up (26 color plus the while).
+  ///\param num the number of the allocated colors. If it is \c 0,
+  ///the default color configuration is set up (26 color plus the white).
   ///If \c num is less then 26/27 then the default color list is cut. Otherwise
   ///the color list is filled repeatedly with the default color list.